@@ -55,7 +55,7 @@ use Carp;
 use Exporter;
 use vars '@ISA', '@EXPORT';
 
-our $VERSION = '1.41';
+our $VERSION = '1.42';
 
 @ISA = ('Exporter');
 
@@ -567,7 +567,10 @@ sub translate_element_node {
 
     my $node_name = 
         $XML::XPathScript::XML_parser eq 'XML::LibXML' ? $node->localname
-      : $XML::XPathScript::XML_parser eq 'XML::XPath'  ? $node->getLocalName 
+      : $XML::XPathScript::XML_parser eq 'XML::XPath'  ? 
+                                 # nasty hack to get around that 
+                                 # the root has no name 
+                                 ( $node->getName && $node->getLocalName )
       :           croak "unsupported parser:  $XML::XPathScript::XML_parser"
       ;
 
